SecureApplicationState class

state hold by the SecureApplicationController

Annotations

Constructors

SecureApplicationState({bool locked = false, bool secured = false, bool paused = false, bool authenticated = false})

Properties

authenticated → bool
final
hashCode → int
The hash code for this object.
no setterinherited
locked → bool
final
paused → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secured → bool
final

Methods

copyWith({bool? locked, bool? secured, bool? paused, bool? authenticated}) → SecureApplicationState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited